@@ -107,7 +107,6 @@ Quick start: simplest usage
 
 """
 
-from __future__ import print_function
 
 __docformat__ = "restructuredtext en"
 
@@ -122,6 +121,7 @@ __all__ = (
 import os
 import sys
 import re
+from difflib import get_close_matches
 from os.path import exists, expanduser
 from optparse import OptionGroup
 from copy import copy
@@ -255,7 +255,8 @@ def _call_validator(
     opttype: str, optdict: Dict[str, Any], option: str, value: Union[List[str], int, str]
 ) -> Union[List[str], int, str]:
     if opttype not in VALIDATORS:
-        raise Exception('Unsupported type "%s"' % opttype)
+        all_validators = "\n - ".join(sorted(VALIDATORS.keys()))
+        raise Exception(f'Unsupported type "{opttype}", supported types are:\n - {all_validators}')
     try:
         return VALIDATORS[opttype](optdict, option, value)
     except TypeError:
@@ -819,7 +820,7 @@ class OptionsManagerMixIn(object):
     # help methods ############################################################
 
     def add_help_section(self, title: str, description: str, level: int = 0) -> None:
-        """add a dummy option section for help purpose """
+        """add a dummy option section for help purpose"""
         group = optik_ext.OptionGroup(
             self.cmdline_parser, title=title.capitalize(), description=description
         )
@@ -850,7 +851,7 @@ class OptionsManagerMixIn(object):
             optik_ext.HelpFormatter.expand_default = self.__expand_default_backup  # type: ignore
 
     def help(self, level: int = 0) -> str:
-        """return the usage string for available options """
+        """return the usage string for available options"""
         # mypy: "HelpFormatter" has no attribute "output_level"
         # set in optik_ext
         self.cmdline_parser.formatter.output_level = level  # type: ignore
@@ -1007,7 +1008,20 @@ class OptionsProviderMixIn(object):
                 return option[1]
         # mypy: Argument 2 to "OptionError" has incompatible type "str"; expected "Option"
         # seems to be working?
-        raise OptionError("no such option %s in section %r" % (opt, self.name), opt)  # type: ignore
+        similar_options = get_close_matches(opt, (str(x[0]) for x in self.options), n=10)
+        if similar_options:
+            raise OptionError(
+                "no such option %s in section %r.\n\nOptions with a similar name are:\n * %s"
+                % (opt, self.name, "\n * ".join(similar_options)),
+                opt,
+            )  # type: ignore
+        else:
+            raise OptionError(
+                "no such option %s in section %r.\n\nNo option with a similar name, "
+                "all available options:\n * %s"
+                % (opt, self.name, "\n * ".join(str(x[0]) for x in self.options)),
+                opt,
+            )  # type: ignore
 
     def all_options(self):
         """return an iterator on available options for this provider
