@@ -30,7 +30,7 @@ class MyError(MyException):
     pass
 
 
-class AbstractClass(object):
+class AbstractClass:
     def to_override(self, whatever):
         raise NotImplementedError()
 
