@@ -17,7 +17,6 @@
 # with logilab-common.  If not, see <http://www.gnu.org/licenses/>.
 """unittest module for logilab.comon.testlib"""
 
-from __future__ import print_function
 
 import os
 import sys
@@ -844,7 +843,7 @@ class TagTC(TestCase):
 
         self.assertEqual(bob(2, 3, 7), 35)
         self.assertTrue(hasattr(bob, "tags"))
-        self.assertSetEqual(bob.tags, set(["testing", "bob"]))
+        self.assertSetEqual(bob.tags, {"testing", "bob"})
 
     def test_tags_class(self):
         tags = self.func.tags
@@ -868,7 +867,7 @@ class TagTC(TestCase):
 
     def test_tagged_class(self):
         def options(tags):
-            class Options(object):
+            class Options:
                 tags_pattern = tags
 
             return Options()
